Name:          shim
Version:       15.8
Release:       2%{?dist}
Summary:       First-stage UEFI bootloader
License:       BSD
URL:           https://github.com/rhboot/shim/
BuildRequires: efi-filesystem
BuildRequires: efi-srpm-macros >= 3-2
BuildRequires: system-sb-certs

ExclusiveArch: %{efi}
# Remove below when time to build for ARM
ExcludeArch:   %{arm} %{ix86}

Source0:       shim.rpmmacros

# keep arches in sync.
# aarch64
Source10:      BOOTAA64.CSV
Source20:      shimaa64.efi
Source30:      mmaa64.efi
Source40:      fbaa64.efi
# 32 bit?
Source11:      BOOTIA32.CSV
Source21:      shimia32.efi
Source31:      mmia32.efi
Source41:      fbia32.efi
# 64 bit
Source12:      BOOTX64.CSV
Source22:      shimx64.efi
Source32:      mmx64.efi
Source42:      fbx64.efi

%include %{SOURCE0}

BuildRequires:	pesign >= 0.112-20.fc27
# We need this because %%{efi} won't expand before choosing where to make
# the src.rpm in koji, and we could be on a non-efi architecture, in which
# case we won't have a valid expansion here...  To be solved in the future
# (shim 16+) by making the unsigned packages all provide "shim-unsigned", so
# we can just BuildRequires that.
%ifarch x86_64
BuildRequires:        %{unsignedx64} = %{shimverx64}
BuildRequires:        %{unsignedia32} = %{shimveria32}
%endif
%ifarch aarch64
BuildRequires:	%{unsignedaa64} = %{shimveraa64}
%endif

%description
Initial UEFI bootloader that handles chaining to a trusted full bootloader
under secure boot environments. This package contains the version signed by
the UEFI signing service.

%define_pkg -a %{efi_arch} -p 1
%if %{efi_has_alt_arch}
%define_pkg -a %{efi_alt_arch}
%endif

%prep
cd %{_builddir}
rm -rf shim-%{version}
mkdir shim-%{version}

%build
export PS4='${LINENO}: '

cd shim-%{version}
%if %{efi_has_alt_arch}
%define_build -a %{efi_alt_arch} -A %{efi_alt_arch_upper} -i %{shimefialt} -b yes -c %{is_alt_signed} -d %{shimdiralt}
%endif
%define_build -a %{efi_arch} -A %{efi_arch_upper} -i %{shimefi} -b yes -c %{is_signed} -d %{shimdir}

%install
rm -rf $RPM_BUILD_ROOT
cd shim-%{version}
install -D -d -m 0755 $RPM_BUILD_ROOT/boot/
install -D -d -m 0700 $RPM_BUILD_ROOT%{efi_esp_root}/
install -D -d -m 0700 $RPM_BUILD_ROOT%{efi_esp_efi}/
install -D -d -m 0700 $RPM_BUILD_ROOT%{efi_esp_dir}/
install -D -d -m 0700 $RPM_BUILD_ROOT%{efi_esp_boot}/

%do_install -a %{efi_arch} -A %{efi_arch_upper} -b %{bootcsv}
%if %{efi_has_alt_arch}
%do_install -a %{efi_alt_arch} -A %{efi_alt_arch_upper} -b %{bootcsvalt}
%endif

%if %{provide_legacy_shim}
install -m 0700 %{shimefi} $RPM_BUILD_ROOT%{efi_esp_dir}/shim.efi
%endif

( cd $RPM_BUILD_ROOT ; find .%{efi_esp_root} -type f ) \
  | sed -e 's/\./\^/' -e 's,^\\\./,.*/,' -e 's,$,$,' > %{__brp_mangle_shebangs_exclude_from_file}

%define_files -a %{efi_arch} -A %{efi_arch_upper}
%if %{efi_has_alt_arch}
%define_files -a %{efi_alt_arch} -A %{efi_alt_arch_upper}
%endif

%if %{provide_legacy_shim}
%{efi_esp_dir}/shim.efi
%endif

%changelog
* Fri Mar 08 2024 Sherif Nagy <sherif@rockylinux.org> - 15.8-2
- 15.8-2 release
